/**
 * @file roadblock.js
 *
 * Tracks the last time the roadblock was seen as well as the number of pages viewed on the client side
 * Only used when the "Use client-side javascript to trigger roadblock" checkbox is selected
 * Used to provide a roadblock when advanced caching is implemented
 */
(function ($) {

Drupal.behaviors.roadblockClientSide = function (context) {
  if(typeof Drupal.settings.roadblock !== "undefined" && typeof Drupal.settings.roadblock.roadblockUseJavascript !== "undefined" && Drupal.settings.roadblock.roadblockUseJavascript) {
    if(typeof Drupal.settings.roadblock.roadblockRanOnce === "undefined") { // prevent from running twice when attachBehaviors is called again
      Drupal.settings.roadblock.roadblockRanOnce = true;
      if(document.cookie.indexOf('roadblock') == -1 || roadblockReadCookie('roadblock') > -1) {
        // skip everything if roadblock cookie exists (indexOf = -1) or roadblock has been shown (value = -1)
        current_pages_viewed = 1; // set for first page in case it hasn't been set at all before
        if (document.cookie.indexOf('roadblock') != -1 && roadblockReadCookie('roadblock') > 0) { // increment number of pages viewed stored in roadblock cookie
          current_pages_viewed = roadblockReadCookie('roadblock') + 1; // $_COOKIE isn't updated with new value until next page load so create variable to use
        }
        roadblockCreateCookie('roadblock', current_pages_viewed, Drupal.settings.roadblock.roadblockLife);
        if (current_pages_viewed > Drupal.settings.roadblock.roadblockPagesDisplayed) {
          window.location = roadblockUpdateQueryStringParameter(window.location.href, 'roadblock', 'true');
        }
      }
    }
  }
};

})(jQuery);


// Adds/updates URL query parameter
// Based on http://stackoverflow.com/a/6021027/1229018
function roadblockUpdateQueryStringParameter(uri, key, value) {
  var re = new RegExp("([?|&])" + key + "=.*?(&|$)", "i");
  separator = uri.indexOf('?') !== -1 ? "&" : "?";
  if (uri.match(re)) {
    return uri.replace(re, '$1' + key + "=" + value + '$2');
  }
  else {
    return uri + separator + key + "=" + value;
  }
}

// Wrappers for Javascript's native cookie handling
// Based on http://www.quirksmode.org/js/cookies.html
function roadblockCreateCookie(name,value,seconds) { // overrode to provide seconds instead of days to match roadblock PHP
	if (seconds) {
		var date = new Date();
		date.setTime(date.getTime()+(seconds*1000));
		var expires = "; expires="+date.toGMTString();
	}
	else var expires = "";
	document.cookie = name+"="+value+expires+"; path=/";
  //console.log(name+"="+value+expires+"; path=/");
}

function roadblockReadCookie(name) {
	var nameEQ = name + "=";
	var ca = document.cookie.split(';');
	for(var i=0;i < ca.length;i++) {
		var c = ca[i];
		while (c.charAt(0)==' ') c = c.substring(1,c.length);
		if (c.indexOf(nameEQ) == 0) return parseInt(c.substring(nameEQ.length,c.length)); // overrode to convert string to integer
	}
	return null;
}

function roadblockEraseCookie(name) {
	roadblockCreateCookie(name,"",-1);
}